@@ -19,7 +19,7 @@
  *
  * This file contains functions for interfacing with the GDB remote protocol.
  *
- * $Id: jtag.h,v 1.28 2008/06/12 20:21:44 joerg_wunsch Exp $
+ * $Id: jtag.h,v 1.29 2008/09/29 20:52:20 joerg_wunsch Exp $
  */
 
 #ifndef JTAG_H
@@ -155,6 +155,8 @@ typedef struct {
 
     gdb_io_reg_def_type *io_reg_defs;
 
+    bool is_xmega;                     // Device is an ATxmega part
+
     jtag1_device_desc_type dev_desc1;  // Device descriptor to download to
                                        // mkI device
     jtag2_device_desc_type dev_desc2;  // Device descriptor to download to
@@ -462,6 +464,7 @@ enum
     EMULATOR_MODE_JTAG		= 0x01,
     EMULATOR_MODE_UNKNOWN	= 0x02,
     EMULATOR_MODE_SPI		= 0x03,
+    EMULATOR_MODE_JTAG_XMEGA    = 0x05,
 
     PAR_IREG			= 0x04,
 
