@@ -19,7 +19,7 @@
  *
  * This file implements target execution handling for the mkII protocol.
  *
- * $Id: jtag2run.cc,v 1.13 2008/06/12 20:21:44 joerg_wunsch Exp $
+ * $Id: jtag2run.cc,v 1.14 2008/10/07 18:14:23 joerg_wunsch Exp $
  */
 
 
@@ -284,7 +284,12 @@ bool jtag2::jtagSingleStep(bool useHLL)
     if (!rv)
         return false;
 
-    (void)eventLoop();
+    if (!eventLoop())
+    {
+        // Break from GDB while waiting for the single-step
+        // to return an EVT_BREAK
+        interruptProgram();
+    }
 
     return true;
 }
