@@ -20,7 +20,7 @@
  * This file implements those parts of class "jtag" that are common
  * for both, the mkI and mkII protocol.
  *
- * $Id: jtaggeneric.cc,v 1.9 2007/08/29 10:58:19 joerg_wunsch Exp $
+ * $Id: jtaggeneric.cc,v 1.10 2008/05/26 11:37:14 joerg_wunsch Exp $
  */
 
 #include <stdarg.h>
@@ -81,14 +81,16 @@ jtag::jtag(const char *jtagDeviceName, char *name, emulator type)
     ctrlPipe = -1;
     device_name = name;
     emu_type = type;
-#ifdef HAVE_LIBUSB
     if (strncmp(jtagDeviceName, "usb", 3) == 0)
       {
+#ifdef HAVE_LIBUSB
 	is_usb = true;
 	openUSB(jtagDeviceName);
+#else
+	throw "avarice has not been compiled with libusb support\n";
+#endif
       }
     else
-#endif
       {
 	// Open modem device for reading and writing and not as controlling
 	// tty because we don't want to get killed if linenoise sends
