@@ -19,7 +19,7 @@
  *
  * This file contains functions for interfacing with the JTAG box.
  *
- * $Id: jtagio.cc,v 1.31 2006/04/07 12:24:14 joerg_wunsch Exp $
+ * $Id: jtagio.cc,v 1.32 2008/06/12 20:21:44 joerg_wunsch Exp $
  */
 
 
@@ -480,9 +480,9 @@ void jtag1::initJtagOnChipDebugging(unsigned long bitrate)
 
     disableProgramming();
 
-    resetProgram();
+    resetProgram(false);
     setJtagParameter(JTAG_P_TIMERS_RUNNING, 0x00);
-    resetProgram();
+    resetProgram(true);
 }
 
 void jtag1::configDaisyChain(void)
