@@ -19,7 +19,7 @@
  *
  * This file contains functions for interfacing with the GDB remote protocol.
  *
- * $Id: remote.cc,v 1.16 2005/06/20 20:35:24 joerg_wunsch Exp $
+ * $Id: remote.cc,v 1.17 2008/06/12 20:21:44 joerg_wunsch Exp $
  */
 
 #include <stdlib.h>
@@ -640,7 +640,7 @@ void talkToGdb(void)
 	break;
 
     case 'R':
-	if (!theJtagICE->resetProgram())
+	if (!theJtagICE->resetProgram(false))
 	    gdbOut("reset failed\n");
         dontSendReply = true;
 	break;
@@ -995,7 +995,7 @@ void talkToGdb(void)
         {
             if (sig == SIGHUP)
             {
-                if (theJtagICE->resetProgram())
+                if (theJtagICE->resetProgram(false))
                 {
                     reportStatusExtended(SIGTRAP);
                 }
